@@ -28,7 +28,7 @@
 
 set dirlist = `ls testB*.sh`
 foreach i ($dirlist)
-	$i
+	./$i
 end
 
 rm -fr *.output
